@@ -1,4 +1,4 @@
-/* Copyright (C) 2000, 2001, 2002, 2003 Shawn Betts
+/* Copyright (C) 2000, 2001, 2002, 2003, 2004 Shawn Betts <sabetts@vcn.bc.ca>
  *
  * This file is part of ratpoison.
  *
@@ -6,12 +6,12 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  * ratpoison is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this software; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
@@ -39,7 +39,7 @@ int frame_left (rp_frame *frame);
 rp_frame *frame_new (rp_screen *s);
 void frame_free (rp_screen *s, rp_frame *f);
 rp_frame *frame_copy (rp_frame *frame);
-char *frame_dump (rp_frame *frame);
-rp_frame *frame_read (char *str);
+char *frame_dump (rp_frame *frame, rp_screen *screen);
+rp_frame *frame_read (char *str, rp_screen *screen);
 
 #endif
